Class: Aws::LicenseManager::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::LicenseManager::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-licensemanager/client.rb,
sig/client.rbs
Overview
An API client for LicenseManager. To construct a client, you need to configure a :region and :credentials.
client = Aws::LicenseManager::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptGrantResponseSuccess, _CheckInLicenseResponseSuccess, _CheckoutBorrowLicenseResponseSuccess, _CheckoutLicenseResponseSuccess, _CreateGrantResponseSuccess, _CreateGrantVersionResponseSuccess, _CreateLicenseAssetGroupResponseSuccess, _CreateLicenseAssetRulesetResponseSuccess, _CreateLicenseConfigurationResponseSuccess, _CreateLicenseConversionTaskForResourceResponseSuccess, _CreateLicenseManagerReportGeneratorResponseSuccess, _CreateLicenseResponseSuccess, _CreateLicenseVersionResponseSuccess, _CreateTokenResponseSuccess, _DeleteGrantResponseSuccess, _DeleteLicenseAssetGroupResponseSuccess, _DeleteLicenseAssetRulesetResponseSuccess, _DeleteLicenseConfigurationResponseSuccess, _DeleteLicenseManagerReportGeneratorResponseSuccess, _DeleteLicenseResponseSuccess, _DeleteTokenResponseSuccess, _ExtendLicenseConsumptionResponseSuccess, _GetAccessTokenResponseSuccess, _GetGrantResponseSuccess, _GetLicenseAssetGroupResponseSuccess, _GetLicenseAssetRulesetResponseSuccess, _GetLicenseConfigurationResponseSuccess, _GetLicenseConversionTaskResponseSuccess, _GetLicenseManagerReportGeneratorResponseSuccess, _GetLicenseResponseSuccess, _GetLicenseUsageResponseSuccess, _GetServiceSettingsResponseSuccess, _ListAssetsForLicenseAssetGroupResponseSuccess, _ListAssociationsForLicenseConfigurationResponseSuccess, _ListDistributedGrantsResponseSuccess, _ListFailuresForLicenseConfigurationOperationsResponseSuccess, _ListLicenseAssetGroupsResponseSuccess, _ListLicenseAssetRulesetsResponseSuccess, _ListLicenseConfigurationsForOrganizationResponseSuccess, _ListLicenseConfigurationsResponseSuccess, _ListLicenseConversionTasksResponseSuccess, _ListLicenseManagerReportGeneratorsResponseSuccess, _ListLicenseSpecificationsForResourceResponseSuccess, _ListLicenseVersionsResponseSuccess, _ListLicensesResponseSuccess, _ListReceivedGrantsForOrganizationResponseSuccess, _ListReceivedGrantsResponseSuccess, _ListReceivedLicensesForOrganizationResponseSuccess, _ListReceivedLicensesResponseSuccess, _ListResourceInventoryResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTokensResponseSuccess, _ListUsageForLicenseConfigurationResponseSuccess, _RejectGrantResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateLicenseAssetGroupResponseSuccess, _UpdateLicenseAssetRulesetResponseSuccess, _UpdateLicenseConfigurationResponseSuccess, _UpdateLicenseManagerReportGeneratorResponseSuccess, _UpdateLicenseSpecificationsForResourceResponseSuccess, _UpdateServiceSettingsResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_grant(params = {}) ⇒ Types::AcceptGrantResponse
Accepts the specified grant.
-
#check_in_license(params = {}) ⇒ Struct
Checks in the specified license.
-
#checkout_borrow_license(params = {}) ⇒ Types::CheckoutBorrowLicenseResponse
Checks out the specified license for offline use.
-
#checkout_license(params = {}) ⇒ Types::CheckoutLicenseResponse
Checks out the specified license.
-
#create_grant(params = {}) ⇒ Types::CreateGrantResponse
Creates a grant for the specified license.
-
#create_grant_version(params = {}) ⇒ Types::CreateGrantVersionResponse
Creates a new version of the specified grant.
-
#create_license(params = {}) ⇒ Types::CreateLicenseResponse
Creates a license.
-
#create_license_asset_group(params = {}) ⇒ Types::CreateLicenseAssetGroupResponse
Creates a license asset group.
-
#create_license_asset_ruleset(params = {}) ⇒ Types::CreateLicenseAssetRulesetResponse
Creates a license asset ruleset.
-
#create_license_configuration(params = {}) ⇒ Types::CreateLicenseConfigurationResponse
Creates a license configuration.
-
#create_license_conversion_task_for_resource(params = {}) ⇒ Types::CreateLicenseConversionTaskForResourceResponse
Creates a new license conversion task.
-
#create_license_manager_report_generator(params = {}) ⇒ Types::CreateLicenseManagerReportGeneratorResponse
Creates a report generator.
-
#create_license_version(params = {}) ⇒ Types::CreateLicenseVersionResponse
Creates a new version of the specified license.
-
#create_token(params = {}) ⇒ Types::CreateTokenResponse
Creates a long-lived token.
-
#delete_grant(params = {}) ⇒ Types::DeleteGrantResponse
Deletes the specified grant.
-
#delete_license(params = {}) ⇒ Types::DeleteLicenseResponse
Deletes the specified license.
-
#delete_license_asset_group(params = {}) ⇒ Types::DeleteLicenseAssetGroupResponse
Deletes a license asset group.
-
#delete_license_asset_ruleset(params = {}) ⇒ Struct
Deletes a license asset ruleset.
-
#delete_license_configuration(params = {}) ⇒ Struct
Deletes the specified license configuration.
-
#delete_license_manager_report_generator(params = {}) ⇒ Struct
Deletes the specified report generator.
-
#delete_token(params = {}) ⇒ Struct
Deletes the specified token.
-
#extend_license_consumption(params = {}) ⇒ Types::ExtendLicenseConsumptionResponse
Extends the expiration date for license consumption.
-
#get_access_token(params = {}) ⇒ Types::GetAccessTokenResponse
Gets a temporary access token to use with AssumeRoleWithWebIdentity.
-
#get_grant(params = {}) ⇒ Types::GetGrantResponse
Gets detailed information about the specified grant.
-
#get_license(params = {}) ⇒ Types::GetLicenseResponse
Gets detailed information about the specified license.
-
#get_license_asset_group(params = {}) ⇒ Types::GetLicenseAssetGroupResponse
Gets a license asset group.
-
#get_license_asset_ruleset(params = {}) ⇒ Types::GetLicenseAssetRulesetResponse
Gets a license asset ruleset.
-
#get_license_configuration(params = {}) ⇒ Types::GetLicenseConfigurationResponse
Gets detailed information about the specified license configuration.
-
#get_license_conversion_task(params = {}) ⇒ Types::GetLicenseConversionTaskResponse
Gets information about the specified license type conversion task.
-
#get_license_manager_report_generator(params = {}) ⇒ Types::GetLicenseManagerReportGeneratorResponse
Gets information about the specified report generator.
-
#get_license_usage(params = {}) ⇒ Types::GetLicenseUsageResponse
Gets detailed information about the usage of the specified license.
-
#get_service_settings(params = {}) ⇒ Types::GetServiceSettingsResponse
Gets the License Manager settings for the current Region.
-
#list_assets_for_license_asset_group(params = {}) ⇒ Types::ListAssetsForLicenseAssetGroupResponse
Lists assets for a license asset group.
-
#list_associations_for_license_configuration(params = {}) ⇒ Types::ListAssociationsForLicenseConfigurationResponse
Lists the resource associations for the specified license configuration.
-
#list_distributed_grants(params = {}) ⇒ Types::ListDistributedGrantsResponse
Lists the grants distributed for the specified license.
-
#list_failures_for_license_configuration_operations(params = {}) ⇒ Types::ListFailuresForLicenseConfigurationOperationsResponse
Lists the license configuration operations that failed.
-
#list_license_asset_groups(params = {}) ⇒ Types::ListLicenseAssetGroupsResponse
Lists license asset groups.
-
#list_license_asset_rulesets(params = {}) ⇒ Types::ListLicenseAssetRulesetsResponse
Lists license asset rulesets.
-
#list_license_configurations(params = {}) ⇒ Types::ListLicenseConfigurationsResponse
Lists the license configurations for your account.
-
#list_license_configurations_for_organization(params = {}) ⇒ Types::ListLicenseConfigurationsForOrganizationResponse
Lists license configurations for an organization.
-
#list_license_conversion_tasks(params = {}) ⇒ Types::ListLicenseConversionTasksResponse
Lists the license type conversion tasks for your account.
-
#list_license_manager_report_generators(params = {}) ⇒ Types::ListLicenseManagerReportGeneratorsResponse
Lists the report generators for your account.
-
#list_license_specifications_for_resource(params = {}) ⇒ Types::ListLicenseSpecificationsForResourceResponse
Describes the license configurations for the specified resource.
-
#list_license_versions(params = {}) ⇒ Types::ListLicenseVersionsResponse
Lists all versions of the specified license.
-
#list_licenses(params = {}) ⇒ Types::ListLicensesResponse
Lists the licenses for your account.
-
#list_received_grants(params = {}) ⇒ Types::ListReceivedGrantsResponse
Lists grants that are received.
-
#list_received_grants_for_organization(params = {}) ⇒ Types::ListReceivedGrantsForOrganizationResponse
Lists the grants received for all accounts in the organization.
-
#list_received_licenses(params = {}) ⇒ Types::ListReceivedLicensesResponse
Lists received licenses.
-
#list_received_licenses_for_organization(params = {}) ⇒ Types::ListReceivedLicensesForOrganizationResponse
Lists the licenses received for all accounts in the organization.
-
#list_resource_inventory(params = {}) ⇒ Types::ListResourceInventoryResponse
Lists resources managed using Systems Manager inventory.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#list_tokens(params = {}) ⇒ Types::ListTokensResponse
Lists your tokens.
-
#list_usage_for_license_configuration(params = {}) ⇒ Types::ListUsageForLicenseConfigurationResponse
Lists all license usage records for a license configuration, displaying license consumption details by resource at a selected point in time.
-
#reject_grant(params = {}) ⇒ Types::RejectGrantResponse
Rejects the specified grant.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
-
#update_license_asset_group(params = {}) ⇒ Types::UpdateLicenseAssetGroupResponse
Updates a license asset group.
-
#update_license_asset_ruleset(params = {}) ⇒ Types::UpdateLicenseAssetRulesetResponse
Updates a license asset ruleset.
-
#update_license_configuration(params = {}) ⇒ Struct
Modifies the attributes of an existing license configuration.
-
#update_license_manager_report_generator(params = {}) ⇒ Struct
Updates a report generator.
-
#update_license_specifications_for_resource(params = {}) ⇒ Struct
Adds or removes the specified license configurations for the specified Amazon Web Services resource.
-
#update_service_settings(params = {}) ⇒ Struct
Updates License Manager settings for the current Region.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-licensemanager/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4402 4403 4404 |
# File 'lib/aws-sdk-licensemanager/client.rb', line 4402 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4405 4406 4407 |
# File 'lib/aws-sdk-licensemanager/client.rb', line 4405 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#accept_grant(params = {}) ⇒ Types::AcceptGrantResponse
Accepts the specified grant.
89 |
# File 'sig/client.rbs', line 89 def accept_grant: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4375 4376 4377 4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 |
# File 'lib/aws-sdk-licensemanager/client.rb', line 4375 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::LicenseManager') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-licensemanager' context[:gem_version] = '1.96.0' Seahorse::Client::Request.new(handlers, context) end |
#check_in_license(params = {}) ⇒ Struct
Checks in the specified license. Check in a license when it is no longer in use.
98 |
# File 'sig/client.rbs', line 98 def check_in_license: ( |
#checkout_borrow_license(params = {}) ⇒ Types::CheckoutBorrowLicenseResponse
Checks out the specified license for offline use.
116 |
# File 'sig/client.rbs', line 116 def checkout_borrow_license: ( |
#checkout_license(params = {}) ⇒ Types::CheckoutLicenseResponse
Checks out the specified license.
149 |
# File 'sig/client.rbs', line 149 def checkout_license: ( |
#create_grant(params = {}) ⇒ Types::CreateGrantResponse
Creates a grant for the specified license. A grant shares the use of license entitlements with a specific Amazon Web Services account, an organization, or an organizational unit (OU). For more information, see Granted licenses in License Manager in the License Manager User Guide.
173 |
# File 'sig/client.rbs', line 173 def create_grant: ( |
#create_grant_version(params = {}) ⇒ Types::CreateGrantVersionResponse
Creates a new version of the specified grant. For more information, see Granted licenses in License Manager in the License Manager User Guide.
196 |
# File 'sig/client.rbs', line 196 def create_grant_version: ( |
#create_license(params = {}) ⇒ Types::CreateLicenseResponse
Creates a license.
217 |
# File 'sig/client.rbs', line 217 def create_license: ( |
#create_license_asset_group(params = {}) ⇒ Types::CreateLicenseAssetGroupResponse
Creates a license asset group.
257 |
# File 'sig/client.rbs', line 257 def create_license_asset_group: ( |
#create_license_asset_ruleset(params = {}) ⇒ Types::CreateLicenseAssetRulesetResponse
Creates a license asset ruleset.
287 |
# File 'sig/client.rbs', line 287 def create_license_asset_ruleset: ( |
#create_license_configuration(params = {}) ⇒ Types::CreateLicenseConfigurationResponse
Creates a license configuration.
A license configuration is an abstraction of a customer license agreement that can be consumed and enforced by License Manager. Components include specifications for the license type (licensing by instance, socket, CPU, or vCPU), allowed tenancy (shared tenancy, Dedicated Instance, Dedicated Host, or all of these), license affinity to host (how long a license must be associated with a host), and the number of licenses purchased and used.
308 |
# File 'sig/client.rbs', line 308 def create_license_configuration: ( |
#create_license_conversion_task_for_resource(params = {}) ⇒ Types::CreateLicenseConversionTaskForResourceResponse
Creates a new license conversion task.
334 |
# File 'sig/client.rbs', line 334 def create_license_conversion_task_for_resource: ( |
#create_license_manager_report_generator(params = {}) ⇒ Types::CreateLicenseManagerReportGeneratorResponse
Creates a report generator.
362 |
# File 'sig/client.rbs', line 362 def create_license_manager_report_generator: ( |
#create_license_version(params = {}) ⇒ Types::CreateLicenseVersionResponse
Creates a new version of the specified license.
393 |
# File 'sig/client.rbs', line 393 def create_license_version: ( |
#create_token(params = {}) ⇒ Types::CreateTokenResponse
Creates a long-lived token.
A refresh token is a JWT token used to get an access token. With an access token, you can call AssumeRoleWithWebIdentity to get role credentials that you can use to call License Manager to manage the specified license.
430 |
# File 'sig/client.rbs', line 430 def create_token: ( |
#delete_grant(params = {}) ⇒ Types::DeleteGrantResponse
Deletes the specified grant.
446 |
# File 'sig/client.rbs', line 446 def delete_grant: ( |
#delete_license(params = {}) ⇒ Types::DeleteLicenseResponse
Deletes the specified license.
459 |
# File 'sig/client.rbs', line 459 def delete_license: ( |
#delete_license_asset_group(params = {}) ⇒ Types::DeleteLicenseAssetGroupResponse
Deletes a license asset group.
470 |
# File 'sig/client.rbs', line 470 def delete_license_asset_group: ( |
#delete_license_asset_ruleset(params = {}) ⇒ Struct
Deletes a license asset ruleset.
479 |
# File 'sig/client.rbs', line 479 def delete_license_asset_ruleset: ( |
#delete_license_configuration(params = {}) ⇒ Struct
Deletes the specified license configuration.
You cannot delete a license configuration that is in use.
488 |
# File 'sig/client.rbs', line 488 def delete_license_configuration: ( |
#delete_license_manager_report_generator(params = {}) ⇒ Struct
Deletes the specified report generator.
This action deletes the report generator, which stops it from generating future reports. The action cannot be reversed. It has no effect on the previous reports from this generator.
497 |
# File 'sig/client.rbs', line 497 def delete_license_manager_report_generator: ( |
#delete_token(params = {}) ⇒ Struct
Deletes the specified token. Must be called in the license home Region.
506 |
# File 'sig/client.rbs', line 506 def delete_token: ( |
#extend_license_consumption(params = {}) ⇒ Types::ExtendLicenseConsumptionResponse
Extends the expiration date for license consumption.
517 |
# File 'sig/client.rbs', line 517 def extend_license_consumption: ( |
#get_access_token(params = {}) ⇒ Types::GetAccessTokenResponse
Gets a temporary access token to use with AssumeRoleWithWebIdentity. Access tokens are valid for one hour.
528 |
# File 'sig/client.rbs', line 528 def get_access_token: ( |
#get_grant(params = {}) ⇒ Types::GetGrantResponse
Gets detailed information about the specified grant.
539 |
# File 'sig/client.rbs', line 539 def get_grant: ( |
#get_license(params = {}) ⇒ Types::GetLicenseResponse
Gets detailed information about the specified license.
550 |
# File 'sig/client.rbs', line 550 def get_license: ( |
#get_license_asset_group(params = {}) ⇒ Types::GetLicenseAssetGroupResponse
Gets a license asset group.
561 |
# File 'sig/client.rbs', line 561 def get_license_asset_group: ( |
#get_license_asset_ruleset(params = {}) ⇒ Types::GetLicenseAssetRulesetResponse
Gets a license asset ruleset.
571 |
# File 'sig/client.rbs', line 571 def get_license_asset_ruleset: ( |
#get_license_configuration(params = {}) ⇒ Types::GetLicenseConfigurationResponse
Gets detailed information about the specified license configuration.
598 |
# File 'sig/client.rbs', line 598 def get_license_configuration: ( |
#get_license_conversion_task(params = {}) ⇒ Types::GetLicenseConversionTaskResponse
Gets information about the specified license type conversion task.
616 |
# File 'sig/client.rbs', line 616 def get_license_conversion_task: ( |
#get_license_manager_report_generator(params = {}) ⇒ Types::GetLicenseManagerReportGeneratorResponse
Gets information about the specified report generator.
626 |
# File 'sig/client.rbs', line 626 def get_license_manager_report_generator: ( |
#get_license_usage(params = {}) ⇒ Types::GetLicenseUsageResponse
Gets detailed information about the usage of the specified license.
636 |
# File 'sig/client.rbs', line 636 def get_license_usage: ( |
#get_service_settings(params = {}) ⇒ Types::GetServiceSettingsResponse
Gets the License Manager settings for the current Region.
653 |
# File 'sig/client.rbs', line 653 def get_service_settings: ( |
#list_assets_for_license_asset_group(params = {}) ⇒ Types::ListAssetsForLicenseAssetGroupResponse
Lists assets for a license asset group.
663 |
# File 'sig/client.rbs', line 663 def list_assets_for_license_asset_group: ( |
#list_associations_for_license_configuration(params = {}) ⇒ Types::ListAssociationsForLicenseConfigurationResponse
Lists the resource associations for the specified license configuration.
Resource associations need not consume licenses from a license configuration. For example, an AMI or a stopped instance might not consume a license (depending on the license rules).
677 |
# File 'sig/client.rbs', line 677 def list_associations_for_license_configuration: ( |
#list_distributed_grants(params = {}) ⇒ Types::ListDistributedGrantsResponse
Lists the grants distributed for the specified license.
690 |
# File 'sig/client.rbs', line 690 def list_distributed_grants: ( |
#list_failures_for_license_configuration_operations(params = {}) ⇒ Types::ListFailuresForLicenseConfigurationOperationsResponse
Lists the license configuration operations that failed.
709 |
# File 'sig/client.rbs', line 709 def list_failures_for_license_configuration_operations: ( |
#list_license_asset_groups(params = {}) ⇒ Types::ListLicenseAssetGroupsResponse
Lists license asset groups.
722 |
# File 'sig/client.rbs', line 722 def list_license_asset_groups: ( |
#list_license_asset_rulesets(params = {}) ⇒ Types::ListLicenseAssetRulesetsResponse
Lists license asset rulesets.
740 |
# File 'sig/client.rbs', line 740 def list_license_asset_rulesets: ( |
#list_license_configurations(params = {}) ⇒ Types::ListLicenseConfigurationsResponse
Lists the license configurations for your account.
759 |
# File 'sig/client.rbs', line 759 def list_license_configurations: ( |
#list_license_configurations_for_organization(params = {}) ⇒ Types::ListLicenseConfigurationsForOrganizationResponse
Lists license configurations for an organization.
778 |
# File 'sig/client.rbs', line 778 def list_license_configurations_for_organization: ( |
#list_license_conversion_tasks(params = {}) ⇒ Types::ListLicenseConversionTasksResponse
Lists the license type conversion tasks for your account.
797 |
# File 'sig/client.rbs', line 797 def list_license_conversion_tasks: ( |
#list_license_manager_report_generators(params = {}) ⇒ Types::ListLicenseManagerReportGeneratorsResponse
Lists the report generators for your account.
815 |
# File 'sig/client.rbs', line 815 def list_license_manager_report_generators: ( |
#list_license_specifications_for_resource(params = {}) ⇒ Types::ListLicenseSpecificationsForResourceResponse
Describes the license configurations for the specified resource.
833 |
# File 'sig/client.rbs', line 833 def list_license_specifications_for_resource: ( |
#list_license_versions(params = {}) ⇒ Types::ListLicenseVersionsResponse
Lists all versions of the specified license.
846 |
# File 'sig/client.rbs', line 846 def list_license_versions: ( |
#list_licenses(params = {}) ⇒ Types::ListLicensesResponse
Lists the licenses for your account.
859 |
# File 'sig/client.rbs', line 859 def list_licenses: ( |
#list_received_grants(params = {}) ⇒ Types::ListReceivedGrantsResponse
Lists grants that are received. Received grants are grants created while specifying the recipient as this Amazon Web Services account, your organization, or an organizational unit (OU) to which this member account belongs.
878 |
# File 'sig/client.rbs', line 878 def list_received_grants: ( |
#list_received_grants_for_organization(params = {}) ⇒ Types::ListReceivedGrantsForOrganizationResponse
Lists the grants received for all accounts in the organization.
897 |
# File 'sig/client.rbs', line 897 def list_received_grants_for_organization: ( |
#list_received_licenses(params = {}) ⇒ Types::ListReceivedLicensesResponse
Lists received licenses.
916 |
# File 'sig/client.rbs', line 916 def list_received_licenses: ( |
#list_received_licenses_for_organization(params = {}) ⇒ Types::ListReceivedLicensesForOrganizationResponse
Lists the licenses received for all accounts in the organization.
935 |
# File 'sig/client.rbs', line 935 def list_received_licenses_for_organization: ( |
#list_resource_inventory(params = {}) ⇒ Types::ListResourceInventoryResponse
Lists resources managed using Systems Manager inventory.
953 |
# File 'sig/client.rbs', line 953 def list_resource_inventory: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource. For more information about tagging support in License Manager, see the TagResource operation.
971 |
# File 'sig/client.rbs', line 971 def list_tags_for_resource: ( |
#list_tokens(params = {}) ⇒ Types::ListTokensResponse
Lists your tokens.
982 |
# File 'sig/client.rbs', line 982 def list_tokens: ( |
#list_usage_for_license_configuration(params = {}) ⇒ Types::ListUsageForLicenseConfigurationResponse
Lists all license usage records for a license configuration, displaying license consumption details by resource at a selected point in time. Use this action to audit the current license consumption for any license inventory and configuration.
1001 |
# File 'sig/client.rbs', line 1001 def list_usage_for_license_configuration: ( |
#reject_grant(params = {}) ⇒ Types::RejectGrantResponse
Rejects the specified grant.
1021 |
# File 'sig/client.rbs', line 1021 def reject_grant: ( |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource. The following resources support tagging in License Manager:
-
Licenses
-
Grants
-
License configurations
-
Report generators
1030 |
# File 'sig/client.rbs', line 1030 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
1045 |
# File 'sig/client.rbs', line 1045 def untag_resource: ( |
#update_license_asset_group(params = {}) ⇒ Types::UpdateLicenseAssetGroupResponse
Updates a license asset group.
1057 |
# File 'sig/client.rbs', line 1057 def update_license_asset_group: ( |
#update_license_asset_ruleset(params = {}) ⇒ Types::UpdateLicenseAssetRulesetResponse
Updates a license asset ruleset.
1083 |
# File 'sig/client.rbs', line 1083 def update_license_asset_ruleset: ( |
#update_license_configuration(params = {}) ⇒ Struct
Modifies the attributes of an existing license configuration.
1098 |
# File 'sig/client.rbs', line 1098 def update_license_configuration: ( |
#update_license_manager_report_generator(params = {}) ⇒ Struct
Updates a report generator.
After you make changes to a report generator, it starts generating new reports within 60 minutes of being updated.
1118 |
# File 'sig/client.rbs', line 1118 def update_license_manager_report_generator: ( |
#update_license_specifications_for_resource(params = {}) ⇒ Struct
Adds or removes the specified license configurations for the specified Amazon Web Services resource.
You can update the license specifications of AMIs, instances, and hosts. You cannot update the license specifications for launch templates and CloudFormation templates, as they send license configurations to the operation that creates the resource.
1141 |
# File 'sig/client.rbs', line 1141 def update_license_specifications_for_resource: ( |
#update_service_settings(params = {}) ⇒ Struct
Updates License Manager settings for the current Region.
1162 |
# File 'sig/client.rbs', line 1162 def update_service_settings: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4395 4396 4397 |
# File 'lib/aws-sdk-licensemanager/client.rb', line 4395 def waiter_names [] end |