Class: Aws::LicenseManager::Types::CreateTokenRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManager::Types::CreateTokenRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Idempotency token, valid for 10 minutes.
-
#expiration_in_days ⇒ Integer
Token expiration, in days, counted from token creation.
-
#license_arn ⇒ String
Amazon Resource Name (ARN) of the license.
-
#role_arns ⇒ Array<String>
Amazon Resource Name (ARN) of the IAM roles to embed in the token.
-
#token_properties ⇒ Array<String>
Data specified by the caller to be included in the JWT token.
Instance Attribute Details
#client_token ⇒ String
Idempotency token, valid for 10 minutes.
1091 1092 1093 1094 1095 1096 1097 1098 1099 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 1091 class CreateTokenRequest < Struct.new( :license_arn, :role_arns, :expiration_in_days, :token_properties, :client_token) SENSITIVE = [] include Aws::Structure end |
#expiration_in_days ⇒ Integer
Token expiration, in days, counted from token creation. The default is 365 days.
1091 1092 1093 1094 1095 1096 1097 1098 1099 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 1091 class CreateTokenRequest < Struct.new( :license_arn, :role_arns, :expiration_in_days, :token_properties, :client_token) SENSITIVE = [] include Aws::Structure end |
#license_arn ⇒ String
Amazon Resource Name (ARN) of the license. The ARN is mapped to the aud claim of the JWT token.
1091 1092 1093 1094 1095 1096 1097 1098 1099 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 1091 class CreateTokenRequest < Struct.new( :license_arn, :role_arns, :expiration_in_days, :token_properties, :client_token) SENSITIVE = [] include Aws::Structure end |
#role_arns ⇒ Array<String>
Amazon Resource Name (ARN) of the IAM roles to embed in the token. License Manager does not check whether the roles are in use.
1091 1092 1093 1094 1095 1096 1097 1098 1099 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 1091 class CreateTokenRequest < Struct.new( :license_arn, :role_arns, :expiration_in_days, :token_properties, :client_token) SENSITIVE = [] include Aws::Structure end |
#token_properties ⇒ Array<String>
Data specified by the caller to be included in the JWT token. The data is mapped to the amr claim of the JWT token.
1091 1092 1093 1094 1095 1096 1097 1098 1099 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 1091 class CreateTokenRequest < Struct.new( :license_arn, :role_arns, :expiration_in_days, :token_properties, :client_token) SENSITIVE = [] include Aws::Structure end |