Class: Aws::LicenseManager::Types::ListAssetsForLicenseAssetGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManager::Types::ListAssetsForLicenseAssetGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_type ⇒ String
Asset type.
-
#license_asset_group_arn ⇒ String
Amazon Resource Name (ARN) of the license asset group.
-
#max_results ⇒ Integer
Maximum number of results to return in a single call.
-
#next_token ⇒ String
Token for the next set of results.
Instance Attribute Details
#asset_type ⇒ String
Asset type. The possible values are Instance | License | LicenseConfiguration.
2854 2855 2856 2857 2858 2859 2860 2861 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 2854 class ListAssetsForLicenseAssetGroupRequest < Struct.new( :license_asset_group_arn, :asset_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#license_asset_group_arn ⇒ String
Amazon Resource Name (ARN) of the license asset group.
2854 2855 2856 2857 2858 2859 2860 2861 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 2854 class ListAssetsForLicenseAssetGroupRequest < Struct.new( :license_asset_group_arn, :asset_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of results to return in a single call.
2854 2855 2856 2857 2858 2859 2860 2861 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 2854 class ListAssetsForLicenseAssetGroupRequest < Struct.new( :license_asset_group_arn, :asset_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for the next set of results.
2854 2855 2856 2857 2858 2859 2860 2861 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 2854 class ListAssetsForLicenseAssetGroupRequest < Struct.new( :license_asset_group_arn, :asset_type, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |