Class: Aws::LicenseManager::Types::ListLicenseAssetGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManager::Types::ListLicenseAssetGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Filters to scope the results.
-
#max_results ⇒ Integer
Maximum number of results to return in a single call.
-
#next_token ⇒ String
Token for the next set of results.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Filters to scope the results. Following filters are supported
LicenseAssetRulesetArn
^
3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3037 class ListLicenseAssetGroupsRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of results to return in a single call.
3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3037 class ListLicenseAssetGroupsRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for the next set of results.
3037 3038 3039 3040 3041 3042 3043 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3037 class ListLicenseAssetGroupsRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |