Class: Aws::LicenseManager::Types::ListLicenseAssetRulesetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManager::Types::ListLicenseAssetRulesetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Filters to scope the results.
-
#max_results ⇒ Integer
Maximum number of results to return in a single call.
-
#next_token ⇒ String
Token for the next set of results.
-
#show_aws_managed_license_asset_rulesets ⇒ Boolean
Specifies whether to show License Manager managed license asset rulesets.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Filters to scope the results. Following filters are supported
Name
^
3085 3086 3087 3088 3089 3090 3091 3092 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3085 class ListLicenseAssetRulesetsRequest < Struct.new( :filters, :show_aws_managed_license_asset_rulesets, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of results to return in a single call.
3085 3086 3087 3088 3089 3090 3091 3092 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3085 class ListLicenseAssetRulesetsRequest < Struct.new( :filters, :show_aws_managed_license_asset_rulesets, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for the next set of results.
3085 3086 3087 3088 3089 3090 3091 3092 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3085 class ListLicenseAssetRulesetsRequest < Struct.new( :filters, :show_aws_managed_license_asset_rulesets, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#show_aws_managed_license_asset_rulesets ⇒ Boolean
Specifies whether to show License Manager managed license asset rulesets.
3085 3086 3087 3088 3089 3090 3091 3092 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3085 class ListLicenseAssetRulesetsRequest < Struct.new( :filters, :show_aws_managed_license_asset_rulesets, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |