Class: Aws::LicenseManager::Types::ListLicenseConfigurationsForOrganizationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManager::Types::ListLicenseConfigurationsForOrganizationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Filters to scope the results.
-
#license_configuration_arns ⇒ Array<String>
License configuration ARNs.
-
#max_results ⇒ Integer
Maximum number of results to return in a single call.
-
#next_token ⇒ String
Token for the next set of results.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Filters to scope the results.
3122 3123 3124 3125 3126 3127 3128 3129 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3122 class ListLicenseConfigurationsForOrganizationRequest < Struct.new( :license_configuration_arns, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#license_configuration_arns ⇒ Array<String>
License configuration ARNs.
3122 3123 3124 3125 3126 3127 3128 3129 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3122 class ListLicenseConfigurationsForOrganizationRequest < Struct.new( :license_configuration_arns, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of results to return in a single call.
3122 3123 3124 3125 3126 3127 3128 3129 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3122 class ListLicenseConfigurationsForOrganizationRequest < Struct.new( :license_configuration_arns, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for the next set of results.
3122 3123 3124 3125 3126 3127 3128 3129 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3122 class ListLicenseConfigurationsForOrganizationRequest < Struct.new( :license_configuration_arns, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |