Class: Aws::LicenseManager::Types::ListLicenseSpecificationsForResourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManager::Types::ListLicenseSpecificationsForResourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Maximum number of results to return in a single call.
-
#next_token ⇒ String
Token for the next set of results.
-
#resource_arn ⇒ String
Amazon Resource Name (ARN) of a resource that has an associated license configuration.
Instance Attribute Details
#max_results ⇒ Integer
Maximum number of results to return in a single call.
3302 3303 3304 3305 3306 3307 3308 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3302 class ListLicenseSpecificationsForResourceRequest < Struct.new( :resource_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for the next set of results.
3302 3303 3304 3305 3306 3307 3308 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3302 class ListLicenseSpecificationsForResourceRequest < Struct.new( :resource_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
Amazon Resource Name (ARN) of a resource that has an associated license configuration.
3302 3303 3304 3305 3306 3307 3308 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3302 class ListLicenseSpecificationsForResourceRequest < Struct.new( :resource_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |