Class: Aws::LicenseManager::Types::ListReceivedGrantsForOrganizationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManager::Types::ListReceivedGrantsForOrganizationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Filters to scope the results.
-
#license_arn ⇒ String
The Amazon Resource Name (ARN) of the received license.
-
#max_results ⇒ Integer
Maximum number of results to return in a single call.
-
#next_token ⇒ String
Token for the next set of results.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Filters to scope the results. The following filters are supported:
-
ParentArn -
GranteePrincipalArn
3440 3441 3442 3443 3444 3445 3446 3447 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3440 class ListReceivedGrantsForOrganizationRequest < Struct.new( :license_arn, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#license_arn ⇒ String
The Amazon Resource Name (ARN) of the received license.
3440 3441 3442 3443 3444 3445 3446 3447 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3440 class ListReceivedGrantsForOrganizationRequest < Struct.new( :license_arn, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of results to return in a single call.
3440 3441 3442 3443 3444 3445 3446 3447 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3440 class ListReceivedGrantsForOrganizationRequest < Struct.new( :license_arn, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for the next set of results.
3440 3441 3442 3443 3444 3445 3446 3447 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3440 class ListReceivedGrantsForOrganizationRequest < Struct.new( :license_arn, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |