Class: Aws::LicenseManager::Types::ListReceivedGrantsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManager::Types::ListReceivedGrantsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Filters to scope the results.
-
#grant_arns ⇒ Array<String>
Amazon Resource Names (ARNs) of the grants.
-
#max_results ⇒ Integer
Maximum number of results to return in a single call.
-
#next_token ⇒ String
Token for the next set of results.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Filters to scope the results. The following filters are supported:
-
ProductSKU -
LicenseIssuerName -
LicenseArn -
GrantStatus -
GranterAccountId
3501 3502 3503 3504 3505 3506 3507 3508 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3501 class ListReceivedGrantsRequest < Struct.new( :grant_arns, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#grant_arns ⇒ Array<String>
Amazon Resource Names (ARNs) of the grants.
3501 3502 3503 3504 3505 3506 3507 3508 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3501 class ListReceivedGrantsRequest < Struct.new( :grant_arns, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of results to return in a single call.
3501 3502 3503 3504 3505 3506 3507 3508 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3501 class ListReceivedGrantsRequest < Struct.new( :grant_arns, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for the next set of results.
3501 3502 3503 3504 3505 3506 3507 3508 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3501 class ListReceivedGrantsRequest < Struct.new( :grant_arns, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |