Class: Aws::LicenseManager::Types::ListReceivedLicensesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManager::Types::ListReceivedLicensesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Filters to scope the results.
-
#license_arns ⇒ Array<String>
Amazon Resource Names (ARNs) of the licenses.
-
#max_results ⇒ Integer
Maximum number of results to return in a single call.
-
#next_token ⇒ String
Token for the next set of results.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Filters to scope the results. The following filters are supported:
-
ProductSKU -
Status -
Fingerprint -
IssuerName -
Beneficiary
3598 3599 3600 3601 3602 3603 3604 3605 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3598 class ListReceivedLicensesRequest < Struct.new( :license_arns, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#license_arns ⇒ Array<String>
Amazon Resource Names (ARNs) of the licenses.
3598 3599 3600 3601 3602 3603 3604 3605 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3598 class ListReceivedLicensesRequest < Struct.new( :license_arns, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of results to return in a single call.
3598 3599 3600 3601 3602 3603 3604 3605 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3598 class ListReceivedLicensesRequest < Struct.new( :license_arns, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for the next set of results.
3598 3599 3600 3601 3602 3603 3604 3605 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3598 class ListReceivedLicensesRequest < Struct.new( :license_arns, :filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |