Class: Aws::LicenseManager::Types::ListResourceInventoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManager::Types::ListResourceInventoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::InventoryFilter>
Filters to scope the results.
-
#max_results ⇒ Integer
Maximum number of results to return in a single call.
-
#next_token ⇒ String
Token for the next set of results.
Instance Attribute Details
#filters ⇒ Array<Types::InventoryFilter>
Filters to scope the results. The following filters and logical operators are supported:
-
account_id- The ID of the Amazon Web Services account that owns the resource. Logical operators areEQUALS|NOT_EQUALS. -
application_name- The name of the application. Logical operators areEQUALS|BEGINS_WITH. -
license_included- The type of license included. Logical operators areEQUALS|NOT_EQUALS. Possible values aresql-server-enterprise|sql-server-standard|sql-server-web|windows-server-datacenter. -
platform- The platform of the resource. Logical operators areEQUALS|BEGINS_WITH. -
resource_id- The ID of the resource. Logical operators areEQUALS|NOT_EQUALS. -
‘tag:<key>` - The key/value combination of a tag assigned to the resource. Logical operators are
EQUALS(single account) orEQUALS|NOT_EQUALS(cross account).
3653 3654 3655 3656 3657 3658 3659 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3653 class ListResourceInventoryRequest < Struct.new( :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of results to return in a single call.
3653 3654 3655 3656 3657 3658 3659 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3653 class ListResourceInventoryRequest < Struct.new( :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for the next set of results.
3653 3654 3655 3656 3657 3658 3659 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3653 class ListResourceInventoryRequest < Struct.new( :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |