Class: Aws::LicenseManager::Types::LicenseConversionContext
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManager::Types::LicenseConversionContext
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanager/types.rb
Overview
Information about a license type conversion task.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#product_codes ⇒ Array<Types::ProductCodeListItem>
Product codes referred to in the license conversion process.
-
#usage_operation ⇒ String
The Usage operation value that corresponds to the license type you are converting your resource from.
Instance Attribute Details
#product_codes ⇒ Array<Types::ProductCodeListItem>
Product codes referred to in the license conversion process.
2658 2659 2660 2661 2662 2663 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 2658 class LicenseConversionContext < Struct.new( :usage_operation, :product_codes) SENSITIVE = [] include Aws::Structure end |
#usage_operation ⇒ String
The Usage operation value that corresponds to the license type you are converting your resource from. For more information about which platforms correspond to which usage operation values see Sample data: usage operation by platform
2658 2659 2660 2661 2662 2663 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 2658 class LicenseConversionContext < Struct.new( :usage_operation, :product_codes) SENSITIVE = [] include Aws::Structure end |