Class: Aws::LicenseManager::Types::MatchingRuleStatement
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManager::Types::MatchingRuleStatement
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanager/types.rb
Overview
Matching rule statement.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#constraint ⇒ String
Constraint.
-
#key_to_match ⇒ String
Key to match.
-
#value_to_match ⇒ Array<String>
Value to match.
Instance Attribute Details
#constraint ⇒ String
Constraint.
3897 3898 3899 3900 3901 3902 3903 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3897 class MatchingRuleStatement < Struct.new( :key_to_match, :constraint, :value_to_match) SENSITIVE = [] include Aws::Structure end |
#key_to_match ⇒ String
Key to match.
The following keys and are supported when the RuleStatement type is ‘Instance`:
-
‘Platform` - The name of the platform. Logical operators are `EQUALS` and `NOT_EQUALS`.
-
‘EC2BillingProduct` - The billing product code. Logical operators are `EQUALS` and `NOT_EQUALS`. Possible values are: `windows-server-enterprise` | `windows-byol` | `rhel` | `rhel-byol` | `rhel-high-availability` | `ubuntu-pro` | `suse-linux` | `sql-server-standard` | `sql-server-enterprise`.
-
‘MarketPlaceProductCode` - The Marketplace product code. Logical operators are `EQUALS` and `NOT_EQUALS`.
-
‘AMIId` - The ID of the AMI. Logical operators are `EQUALS` and `NOT_EQUALS`.
-
‘InstanceType` - The instance type. Logical operators are `EQUALS` and `NOT_EQUALS`.
-
‘InstanceId` - The ID of the instance. Logical operators are `EQUALS` and `NOT_EQUALS`.
-
‘HostId` - The ID of the host. Logical operators are `EQUALS` and `NOT_EQUALS`.
-
‘AccountId` - The ID of the account. Logical operators are `EQUALS` and `NOT_EQUALS`.
The following keys and are supported when the RuleStatement type is ‘License`:
-
‘LicenseArn` - The ARN of a Managed Entitlement License. Logical operators are `EQUALS` and `NOT_EQUALS`.
-
‘ProductSKU` - The productSKU of the license. Logical operators are `EQUALS` and `NOT_EQUALS`.
-
‘Issuer` - The issuer of the license. Logical operators are `EQUALS` and `NOT_EQUALS`.
-
‘Beneficiary` - The beneficiary of the license. Logical operators are `EQUALS` and `NOT_EQUALS`.
-
‘LicenseStatus` - The status of the license. Logical operators are `EQUALS` and `NOT_EQUALS`.
-
‘HomeRegion` - The home region of the license. Logical operators are `EQUALS` and `NOT_EQUALS`.
The following keys and are supported when the RuleStatement type is ‘License Configuration`:
-
‘LicenseConfigurationArn` - The ARN of a self-managed license configuration. Logical operators are `EQUALS` and `NOT_EQUALS`.
-
‘AccountId` - The account of the license configuration. Logical operators are `EQUALS` and `NOT_EQUALS`.
3897 3898 3899 3900 3901 3902 3903 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3897 class MatchingRuleStatement < Struct.new( :key_to_match, :constraint, :value_to_match) SENSITIVE = [] include Aws::Structure end |
#value_to_match ⇒ Array<String>
Value to match.
3897 3898 3899 3900 3901 3902 3903 |
# File 'lib/aws-sdk-licensemanager/types.rb', line 3897 class MatchingRuleStatement < Struct.new( :key_to_match, :constraint, :value_to_match) SENSITIVE = [] include Aws::Structure end |